@@ -1,32 +1,19 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionconvert.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/commonwidgets/selectconvertparameterwidget.h"
 #include "autocreatescripts/commonwidgets/selectmimetypecombobox.h"
 
-#include <KLocalizedString>
-
-#include <QLabel>
 #include "libksieve_debug.h"
-#include <QXmlStreamReader>
+#include <KLocalizedString>
 #include <QGridLayout>
+#include <QLabel>
+#include <QUrl>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -36,15 +23,15 @@ SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGrap
 
 QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QGridLayout *lay = new QGridLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto lay = new QGridLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
-    QLabel *lab = new QLabel(i18n("From:"));
+    auto lab = new QLabel(i18n("From:"));
     lay->addWidget(lab, 0, 0);
 
-    SelectMimeTypeComboBox *fromMimeType = new SelectMimeTypeComboBox;
+    auto fromMimeType = new SelectMimeTypeComboBox;
     connect(fromMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     fromMimeType->setObjectName(QStringLiteral("from"));
     lay->addWidget(fromMimeType, 0, 1);
@@ -52,7 +39,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("To:"));
     lay->addWidget(lab, 0, 2);
 
-    SelectMimeTypeComboBox *toMimeType = new SelectMimeTypeComboBox;
+    auto toMimeType = new SelectMimeTypeComboBox;
     connect(toMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveActionConvert::valueChanged);
     toMimeType->setObjectName(QStringLiteral("to"));
     lay->addWidget(toMimeType, 0, 3);
@@ -60,7 +47,7 @@ QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Parameters:"));
     lay->addWidget(lab, 1, 0);
 
-    SelectConvertParameterWidget *params = new SelectConvertParameterWidget;
+    auto params = new SelectConvertParameterWidget;
     connect(params, &SelectConvertParameterWidget::valueChanged, this, &SieveActionConvert::valueChanged);
     params->setObjectName(QStringLiteral("params"));
     lay->addWidget(params, 1, 1, 2, 3);
@@ -72,13 +59,17 @@ void SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
 {
     int index = 0;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
+                auto fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
                 fromMimeType->setCode(element.readElementText(), name(), error);
             } else if (index == 1) {
-                SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
+                auto toMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("to"));
                 toMimeType->setCode(element.readElementText(), name(), error);
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -86,14 +77,14 @@ void SieveActionConvert::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
             ++index;
         } else if (tagName == QLatin1String("list")) {
-            SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
+            auto params = w->findChild<SelectConvertParameterWidget *>(QStringLiteral("params"));
             params->setCode(AutoCreateScriptUtil::listValue(element), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << "SieveActionConvert::setParamWidgetValue unknown tag " << tagName;
@@ -138,7 +129,9 @@ QString SieveActionConvert::serverNeedsCapability() const
 
 QString SieveActionConvert::help() const
 {
-    return i18n("The \"convert\" action specifies that all body parts with a media type equal to \"media-type\" be converted to the media type in \"media-type\" using conversion parameters.");
+    return i18n(
+        "The \"convert\" action specifies that all body parts with a media type equal to \"media-type\" be converted to the media type in \"media-type\" using "
+        "conversion parameters.");
 }
 
 QUrl SieveActionConvert::href() const
