@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,9 +13,7 @@ RenameScriptJobTest::RenameScriptJobTest(QObject *parent)
 {
 }
 
-RenameScriptJobTest::~RenameScriptJobTest()
-{
-}
+RenameScriptJobTest::~RenameScriptJobTest() = default;
 
 void RenameScriptJobTest::canNotStartByDefault()
 {
