@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,12 +13,6 @@ RegExpConverterTest::RegExpConverterTest(QObject *parent)
 {
 }
 
-static inline QString stringReplaceRegExp(QString s)
-{
-    s.replace(QRegExp(QLatin1String("[\n\t]+")), QStringLiteral(" "));
-    return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
-}
-
 static inline QString stringReplaceRegularExpression(QString s)
 {
     static QRegularExpression reg(QStringLiteral("[\n\t]+"));
@@ -44,7 +38,6 @@ void RegExpConverterTest::convertRegExp()
     QFETCH(QString, input);
     QFETCH(QString, output);
 
-    QCOMPARE(stringReplaceRegExp(input), output);
     QCOMPARE(stringReplaceRegularExpression(input), output);
 }
 
